==> mdm-rpc-0.1.13-sources.jar: com/chinayanghe/msp/mdm/vo/user/UserBasicInformationVo.java <==
package com.chinayanghe.msp.mdm.vo.user;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2017/5/3 0003.
 */
public class UserBasicInformationVo implements Serializable{

    private static final long serialVersionUID = -856337045932364451L;

    // 用户id
    private String id;
    // 用户名
    private String userName;
    //人员编号
    private String pernr;
    //入职日期
    private Date entryDate;
    //人事范围编码
    private String werks;
    //人事范围名称
    private String werksName;
    //人事子范围编码
    private String btrtl;
    //人事子范围名称
    private String btrtlName;
    //员工组编码
    private String persg;
    //员工组名称
    private String persgName;
    //员工子组编码
    private String persk;
    //员工子组名称
    private String perskName;
    //工资范围编码
    private String abkrs;
    //工资范围名称
    private String abkrsName;
    //姓
    private String surname;
    //名
    private String firstName;
    //曾用名
    private String formerName;
    //出生日期
    private Date birthDate;
    //身份证号
    private String idcardNum ;
    //国籍
    private String nationality;
    //国籍名称
    private String nationalityName;
    //出生国家
    private String birthCountry;
    //出生国家描述
    private String birthCountryName;
    //出生省份
    private String birthProvince;
    //出生省份描述
    private String birthProvinceName;
    //婚姻状况
    private String maritalStatus;
    //婚姻状况描述
    private String maritalStatusName;
    //宗教
    private String religion;
    //籍贯(省)
    private String province;
    //籍贯(省)名称
    private String provinceName;
    //籍贯(市)
    private String city;
    //籍贯(区县)
    private String district;
    //民族
    private String nation;
    //民族名称
    private String nationName;
    //派遣公司
    private String dispatchCompany;
    //派遣公司名称
    private String dispatchCompanyname;
    //职务编码
    private String duty;
    //职务名称
    private String dutyName;
    //地址
    private String address;
    //最终学历
    private String lastEducation;
    //紧急联系人
    private String emergencyContact;
    //紧急联系人电话
    private String emergencyNumber;

    // 真实姓名
    private String fullName;
    //性别
    private String sex;
    //手机
    private String mobilePhone;
    //邮箱
    private String email;
    //启用状态 0 启用 1 停用
    private Integer enableStatus;
    //开始日期
    private Date beginDate;
    //结束日期
    private Date endDate;
    // 创建人账号
    private String createName;
    // 创建时间
    private Date createDate;
    // 修改人账号
    private String updateName;
    // 修改时间
    private Date updateDate;
    // 对应的经销商
    private String franchiser;
   //手机序列号
    private String phoneID;

    public String getPhoneID() {
        return phoneID;
    }

    public void setPhoneID(String phoneID) {
        this.phoneID = phoneID;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getPernr() {
        return pernr;
    }

    public void setPernr(String pernr) {
        this.pernr = pernr;
    }

    public Date getEntryDate() {
        return entryDate;
    }

    public void setEntryDate(Date entryDate) {
        this.entryDate = entryDate;
    }

    public String getWerks() {
        return werks;
    }

    public void setWerks(String werks) {
        this.werks = werks;
    }

    public String getWerksName() {
        return werksName;
    }

    public void setWerksName(String werksName) {
        this.werksName = werksName;
    }

    public String getBtrtl() {
        return btrtl;
    }

    public void setBtrtl(String btrtl) {
        this.btrtl = btrtl;
    }

    public String getBtrtlName() {
        return btrtlName;
    }

    public void setBtrtlName(String btrtlName) {
        this.btrtlName = btrtlName;
    }

    public String getPersg() {
        return persg;
    }

    public void setPersg(String persg) {
        this.persg = persg;
    }

    public String getPersgName() {
        return persgName;
    }

    public void setPersgName(String persgName) {
        this.persgName = persgName;
    }

    public String getPersk() {
        return persk;
    }

    public void setPersk(String persk) {
        this.persk = persk;
    }

    public String getPerskName() {
        return perskName;
    }

    public void setPerskName(String perskName) {
        this.perskName = perskName;
    }

    public String getAbkrs() {
        return abkrs;
    }

    public void setAbkrs(String abkrs) {
        this.abkrs = abkrs;
    }

    public String getAbkrsName() {
        return abkrsName;
    }

    public void setAbkrsName(String abkrsName) {
        this.abkrsName = abkrsName;
    }

    public String getSurname() {
        return surname;
    }

    public void setSurname(String surname) {
        this.surname = surname;
    }

    public String getFirstName() {
        return firstName;
    }

    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    public String getFormerName() {
        return formerName;
    }

    public void setFormerName(String formerName) {
        this.formerName = formerName;
    }

    public Date getBirthDate() {
        return birthDate;
    }

    public void setBirthDate(Date birthDate) {
        this.birthDate = birthDate;
    }

    public String getIdcardNum() {
        return idcardNum;
    }

    public void setIdcardNum(String idcardNum) {
        this.idcardNum = idcardNum;
    }

    public String getNationality() {
        return nationality;
    }

    public void setNationality(String nationality) {
        this.nationality = nationality;
    }

    public String getNationalityName() {
        return nationalityName;
    }

    public void setNationalityName(String nationalityName) {
        this.nationalityName = nationalityName;
    }

    public String getMaritalStatus() {
        return maritalStatus;
    }

    public void setMaritalStatus(String maritalStatus) {
        this.maritalStatus = maritalStatus;
    }

    public String getReligion() {
        return religion;
    }

    public void setReligion(String religion) {
        this.religion = religion;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public String getNation() {
        return nation;
    }

    public void setNation(String nation) {
        this.nation = nation;
    }

    public String getNationName() {
        return nationName;
    }

    public void setNationName(String nationName) {
        this.nationName = nationName;
    }

    public String getDispatchCompany() {
        return dispatchCompany;
    }

    public void setDispatchCompany(String dispatchCompany) {
        this.dispatchCompany = dispatchCompany;
    }

    public String getDispatchCompanyname() {
        return dispatchCompanyname;
    }

    public void setDispatchCompanyname(String dispatchCompanyname) {
        this.dispatchCompanyname = dispatchCompanyname;
    }

    public String getDuty() {
        return duty;
    }

    public void setDuty(String duty) {
        this.duty = duty;
    }

    public String getDutyName() {
        return dutyName;
    }

    public void setDutyName(String dutyName) {
        this.dutyName = dutyName;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getLastEducation() {
        return lastEducation;
    }

    public void setLastEducation(String lastEducation) {
        this.lastEducation = lastEducation;
    }

    public String getEmergencyContact() {
        return emergencyContact;
    }

    public void setEmergencyContact(String emergencyContact) {
        this.emergencyContact = emergencyContact;
    }

    public String getEmergencyNumber() {
        return emergencyNumber;
    }

    public void setEmergencyNumber(String emergencyNumber) {
        this.emergencyNumber = emergencyNumber;
    }

    public String getFullName() {
        return fullName;
    }

    public void setFullName(String fullName) {
        this.fullName = fullName;
    }

    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }

    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getBirthCountry() {
        return birthCountry;
    }

    public void setBirthCountry(String birthCountry) {
        this.birthCountry = birthCountry;
    }

    public String getBirthCountryName() {
        return birthCountryName;
    }

    public void setBirthCountryName(String birthCountryName) {
        this.birthCountryName = birthCountryName;
    }

    public String getBirthProvince() {
        return birthProvince;
    }

    public void setBirthProvince(String birthProvince) {
        this.birthProvince = birthProvince;
    }

    public String getBirthProvinceName() {
        return birthProvinceName;
    }

    public void setBirthProvinceName(String birthProvinceName) {
        this.birthProvinceName = birthProvinceName;
    }

    public String getMaritalStatusName() {
        return maritalStatusName;
    }

    public void setMaritalStatusName(String maritalStatusName) {
        this.maritalStatusName = maritalStatusName;
    }

    public String getFranchiser() {
        return franchiser;
    }

    public void setFranchiser(String franchiser) {
        this.franchiser = franchiser;
    }
}

==> mdm-rpc-0.1.16-sources.jar: com/chinayanghe/msp/mdm/vo/user/UserBasicInformationVo.java <==
package com.chinayanghe.msp.mdm.vo.user;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by Administrator on 2017/5/3 0003.
 */
public class UserBasicInformationVo implements Serializable{

    private static final long serialVersionUID = -856337045932364451L;

    // 用户id
    private String id;
    // 用户名
    private String userName;
    //人员编号
    private String pernr;
    //入职日期
    private Date entryDate;
    //人事范围编码
    private String werks;
    //人事范围名称
    private String werksName;
    //人事子范围编码
    private String btrtl;
    //人事子范围名称
    private String btrtlName;
    //员工组编码
    private String persg;
    //员工组名称
    private String persgName;
    //员工子组编码
    private String persk;
    //员工子组名称
    private String perskName;
    //工资范围编码
    private String abkrs;
    //工资范围名称
    private String abkrsName;
    //姓
    private String surname;
    //名
    private String firstName;
    //曾用名
    private String formerName;
    //出生日期
    private Date birthDate;
    //身份证号
    private String idcardNum ;
    //国籍
    private String nationality;
    //国籍名称
    private String nationalityName;
    //出生国家
    private String birthCountry;
    //出生国家描述
    private String birthCountryName;
    //出生省份
    private String birthProvince;
    //出生省份描述
    private String birthProvinceName;
    //婚姻状况
    private String maritalStatus;
    //婚姻状况描述
    private String maritalStatusName;
    //宗教
    private String religion;
    //籍贯(省)
    private String province;
    //籍贯(省)名称
    private String provinceName;
    //籍贯(市)
    private String city;
    //籍贯(区县)
    private String district;
    //民族
    private String nation;
    //民族名称
    private String nationName;
    //派遣公司
    private String dispatchCompany;
    //派遣公司名称
    private String dispatchCompanyname;
    //职务编码
    private String duty;
    //职务名称
    private String dutyName;
    //地址
    private String address;
    //最终学历
    private String lastEducation;
    //紧急联系人
    private String emergencyContact;
    //紧急联系人电话
    private String emergencyNumber;

    // 真实姓名
    private String fullName;
    //性别
    private String sex;
    //手机
    private String mobilePhone;
    //邮箱
    private String email;
    //启用状态 0 启用 1 停用
    private Integer enableStatus;
    //开始日期
    private Date beginDate;
    //结束日期
    private Date endDate;
    // 创建人账号
    private String createName;
    // 创建时间
    private Date createDate;
    // 修改人账号
    private String updateName;
    // 修改时间
    private Date updateDate;
    // 对应的经销商
    private String franchiser;
   //手机序列号
    private String phoneID;

    public String getPhoneID() {
        return phoneID;
    }

    public void setPhoneID(String phoneID) {
        this.phoneID = phoneID;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getPernr() {
        return pernr;
    }

    public void setPernr(String pernr) {
        this.pernr = pernr;
    }

    public Date getEntryDate() {
        return entryDate;
    }

    public void setEntryDate(Date entryDate) {
        this.entryDate = entryDate;
    }

    public String getWerks() {
        return werks;
    }

    public void setWerks(String werks) {
        this.werks = werks;
    }

    public String getWerksName() {
        return werksName;
    }

    public void setWerksName(String werksName) {
        this.werksName = werksName;
    }

    public String getBtrtl() {
        return btrtl;
    }

    public void setBtrtl(String btrtl) {
        this.btrtl = btrtl;
    }

    public String getBtrtlName() {
        return btrtlName;
    }

    public void setBtrtlName(String btrtlName) {
        this.btrtlName = btrtlName;
    }

    public String getPersg() {
        return persg;
    }

    public void setPersg(String persg) {
        this.persg = persg;
    }

    public String getPersgName() {
        return persgName;
    }

    public void setPersgName(String persgName) {
        this.persgName = persgName;
    }

    public String getPersk() {
        return persk;
    }

    public void setPersk(String persk) {
        this.persk = persk;
    }

    public String getPerskName() {
        return perskName;
    }

    public void setPerskName(String perskName) {
        this.perskName = perskName;
    }

    public String getAbkrs() {
        return abkrs;
    }

    public void setAbkrs(String abkrs) {
        this.abkrs = abkrs;
    }

    public String getAbkrsName() {
        return abkrsName;
    }

    public void setAbkrsName(String abkrsName) {
        this.abkrsName = abkrsName;
    }

    public String getSurname() {
        return surname;
    }

    public void setSurname(String surname) {
        this.surname = surname;
    }

    public String getFirstName() {
        return firstName;
    }

    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    public String getFormerName() {
        return formerName;
    }

    public void setFormerName(String formerName) {
        this.formerName = formerName;
    }

    public Date getBirthDate() {
        return birthDate;
    }

    public void setBirthDate(Date birthDate) {
        this.birthDate = birthDate;
    }

    public String getIdcardNum() {
        return idcardNum;
    }

    public void setIdcardNum(String idcardNum) {
        this.idcardNum = idcardNum;
    }

    public String getNationality() {
        return nationality;
    }

    public void setNationality(String nationality) {
        this.nationality = nationality;
    }

    public String getNationalityName() {
        return nationalityName;
    }

    public void setNationalityName(String nationalityName) {
        this.nationalityName = nationalityName;
    }

    public String getMaritalStatus() {
        return maritalStatus;
    }

    public void setMaritalStatus(String maritalStatus) {
        this.maritalStatus = maritalStatus;
    }

    public String getReligion() {
        return religion;
    }

    public void setReligion(String religion) {
        this.religion = religion;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public String getNation() {
        return nation;
    }

    public void setNation(String nation) {
        this.nation = nation;
    }

    public String getNationName() {
        return nationName;
    }

    public void setNationName(String nationName) {
        this.nationName = nationName;
    }

    public String getDispatchCompany() {
        return dispatchCompany;
    }

    public void setDispatchCompany(String dispatchCompany) {
        this.dispatchCompany = dispatchCompany;
    }

    public String getDispatchCompanyname() {
        return dispatchCompanyname;
    }

    public void setDispatchCompanyname(String dispatchCompanyname) {
        this.dispatchCompanyname = dispatchCompanyname;
    }

    public String getDuty() {
        return duty;
    }

    public void setDuty(String duty) {
        this.duty = duty;
    }

    public String getDutyName() {
        return dutyName;
    }

    public void setDutyName(String dutyName) {
        this.dutyName = dutyName;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getLastEducation() {
        return lastEducation;
    }

    public void setLastEducation(String lastEducation) {
        this.lastEducation = lastEducation;
    }

    public String getEmergencyContact() {
        return emergencyContact;
    }

    public void setEmergencyContact(String emergencyContact) {
        this.emergencyContact = emergencyContact;
    }

    public String getEmergencyNumber() {
        return emergencyNumber;
    }

    public void setEmergencyNumber(String emergencyNumber) {
        this.emergencyNumber = emergencyNumber;
    }

    public String getFullName() {
        return fullName;
    }

    public void setFullName(String fullName) {
        this.fullName = fullName;
    }

    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }

    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getBirthCountry() {
        return birthCountry;
    }

    public void setBirthCountry(String birthCountry) {
        this.birthCountry = birthCountry;
    }

    public String getBirthCountryName() {
        return birthCountryName;
    }

    public void setBirthCountryName(String birthCountryName) {
        this.birthCountryName = birthCountryName;
    }

    public String getBirthProvince() {
        return birthProvince;
    }

    public void setBirthProvince(String birthProvince) {
        this.birthProvince = birthProvince;
    }

    public String getBirthProvinceName() {
        return birthProvinceName;
    }

    public void setBirthProvinceName(String birthProvinceName) {
        this.birthProvinceName = birthProvinceName;
    }

    public String getMaritalStatusName() {
        return maritalStatusName;
    }

    public void setMaritalStatusName(String maritalStatusName) {
        this.maritalStatusName = maritalStatusName;
    }

    public String getFranchiser() {
        return franchiser;
    }

    public void setFranchiser(String franchiser) {
        this.franchiser = franchiser;
    }
    /*
    * 岗位对应多角色
     * @return
             */
    private List<UserPositionVo> userPositionVoList ;

    public List<UserPositionVo> getUserPositionVoList() {
        return userPositionVoList;
    }

    public void setUserPositionVoList(List<UserPositionVo> userPositionVoList) {
        this.userPositionVoList = userPositionVoList;
    }
}
